#
# spec file for package python3-pytest-cov
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-pytest-cov
Version:        2.3.1
Release:        3.1
Summary:        Pytest plugin for coverage reporting
License:        MIT
Group:          Development/Languages/Python
Url:            https://github.com/schlamar/pytest-cov
Source:         https://files.pythonhosted.org/packages/source/p/pytest-cov/pytest-cov-%{version}.tar.gz
BuildRequires:  python3-cov-core >= 1.14
BuildRequires:  python3-devel
BuildRequires:  python3-pytest >= 2.2.3
BuildRequires:  python3-setuptools
# Test requirements:
BuildRequires:  python3-process-tests
BuildRequires:  python3-py
BuildRequires:  python3-virtualenv
Requires:       python3-cov-core >= 1.14
Requires:       python3-pytest >= 2.2.3
BuildArch:      noarch

%description
This plugin produces coverage reports.  It supports centralised testing and distributed testing in
both load and each modes.  It also supports coverage of subprocesses.

All features offered by the coverage package should be available, either through pytest-cov or
through coverage's config file.

%prep
%setup -q -n pytest-cov-%{version}

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

%check
export PYTHONPATH=%{buildroot}%{python3_sitelib}:$PYTHONPATH
python3 tests/test_pytest_cov.py

%files
%defattr(-,root,root,-)
%doc LICENSE README.rst AUTHORS.rst CHANGELOG.rst
%{python3_sitelib}/*

%changelog
* Sat Aug 20 2016 arun@gmx.de
- update to version 2.3.1:
  * Fixed regression causing spurious errors when xdist was used. See
    [#124].
  * Fixed DeprecationWarning about incorrect addoption
    use. Contributed by Florian Bruhin in PR#127.
  * Fixed deprecated use of funcarg fixture API. Contributed by Daniel
    Hahler in PR#125.
* Thu Jul  7 2016 arun@gmx.de
- update to version 2.3.0:
  * Add support for specifying output location for html, xml, and
    annotate report. Contributed by Patrick Lannigan in PR#113.
  * Fix bug hiding test failure when cov-fail-under failed.
  * For coverage >= 4.0, match the default behaviour of coverage
    report and error if coverage fails to find the source instead of
    just printing a warning. Contributed by David Szotten in PR#116.
  * Fixed bug occurred when bare --cov parameter was used with
    xdist. Contributed by Michael Elovskikh in PR#120.
  * Add support for skip_covered and added
  - -cov-report=term-skip-covered command line options. Contributed
    by Saurabh Kumar in PR#115.
* Sun May  8 2016 arun@gmx.de
- specfile:
  * updated source url to files.pythonhosted.org
* Sat Jan 30 2016 arun@gmx.de
- specfile:
  * update copyright year
- update to version 2.2.1:
  * Fixed incorrect merging of coverage data when xdist was used and
    coverage was >= 4.0.
* Fri Oct 23 2015 arun@gmx.de
- specfile:
  * added python3-process-tests as requirement
  * set PYTHONPATH to include new package for tests
  * added AUTHORS.rst CHANGELOG.rst, renamed LICENSE.txt->LICENSE
* Sun Oct  4 2015 arun@gmx.de
- update to version 2.2.0:
  * Added support for changing working directory in tests. Previously
    changing working directory would disable coverage measurements in
    suprocesses.
  * Fixed broken handling for --cov-report=annotate.
* Sun Sep 27 2015 arun@gmx.de
- update to version 2.1.0:
  * Added support for coverage 4.0b2.
  * Added the --cov-append command line options. Contributed by
    Christian Ledermann in PR#80.
* Sat Aug 15 2015 arun@gmx.de
- specfile:
  * updaet location of test file in %%check
- update to version 2.0.0:
  * Added "--cov-fail-under", akin to the new "fail_under" option in `coverage-4.0`
    (automatically activated if there's a "[report] fail_under = ..." in ".coveragerc").
  * Changed "--cov-report=term" to automatically upgrade to "--cov-report=term-missing"
    if there's "[run] show_missing = True" in ".coveragerc".
  * Changed "--cov" so it can be used with no path argument (in wich case the source
    settings from ".coveragerc" will be used instead).
  * Fixed `.pth` installation to work in all cases (install, easy_install, wheels, develop etc).
  * Fixed `.pth` uninstallation to work for wheel installs.
  * Support for coverage 4.0.
  * Data file suffixing changed to use coverage's "data_suffix=True" option (instead of the
    custom suffixing).
  * Avoid warning about missing coverage data (just like "coverage.control.process_startup").
  * Fixed a race condition when running with xdist (all the workers tried to combine the files).
    It's possible that this issue is not present in `pytest-cov 1.8.X`.
* Fri Jan  9 2015 dimstar@opensuse.org
- Bump version dependency of python-cov-core to 1.14, as specified
  in requires.txt.
* Wed Dec 31 2014 arun@gmx.de
- specfile: updated url
- update to version 1.8.1:
  * do not run `assert True` in tests
  * run tests with pypy3
  * use tryfirst marker in load_initial_conftests
  * pin coverage dependency
  * naming convention in coverage changed at version 4.0a0
- changes from version 1.8.0:
  * add support to disable output
  * increase required dependencies
  * run coverage manually if test is in a new process
  * prevent error if --looponfail is set
  * set py dependency to 1.4.21 or greater
  * Added test for --boxed.
  * Set cov-core dependency to 1.13.0
* Wed Jul 30 2014 toddrme2178@gmail.com
- Update to 1.7.0
  * No upstream changelog
* Thu Feb  6 2014 speilicke@suse.com
- Initial version
